@@ -28,9 +28,14 @@ class EssbasicClient(AbstractClient):
 
     def ChannelBatchCancelFlows(self, request):
         """指定需要批量撤销的签署流程Id，批量撤销合同
-        客户指定需要撤销的签署流程Id，最多100个，超过100不处理；接口失败后返回错误信息
-        注意:
-        能撤回合同的只能是合同的发起人或者发起企业的超管、法人
+        客户指定需要撤销的签署流程Id，最多100个，超过100不处理；
+
+        **满足撤销条件的合同会发起异步撤销流程，不满足撤销条件的合同返回失败原因。**
+
+        **合同撤销成功后，会通过合同状态为 CANCEL 的回调消息通知调用方 [具体可参考回调消息](https://qian.tencent.com/developers/scenes/partner/callback_data_types#-%E5%90%88%E5%90%8C%E7%8A%B6%E6%80%81%E9%80%9A%E7%9F%A5---flowstatuschange)**
+
+        **注意:
+        能撤回合同的只能是合同的发起人或者发起企业的超管、法人**
 
         :param request: Request instance for ChannelBatchCancelFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelBatchCancelFlowsRequest`
@@ -324,8 +329,15 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateMultiFlowSignQRCode(self, request):
-        """此接口（ChannelCreateMultiFlowSignQRCode）用于创建一码多扫签署流程二维码。
-        适用的模版仅限于B2C（1、无序签署，2、顺序签署时B静默签署，3、顺序签署时B非首位签署）、单C的模版，且模版中发起方没有填写控件。
+        """此接口（ChannelCreateMultiFlowSignQRCode）用于创建一码多扫流程签署二维码。 适用场景：无需填写签署人信息，可通过模板id生成签署二维码，签署人可通过扫描二维码补充签署信息进行实名签署。常用于提前不知道签署人的身份信息场景，例如：劳务工招工、大批量员工入职等场景。
+
+        **本接口适用于发起方没有填写控件的 B2C或者单C模板**
+
+        **若是B2C模板,还要满足以下任意一个条件**
+
+        - 模板中配置的签署顺序是无序
+        - B端企业的签署方式是静默签署
+        - B端企业是非首位签署
 
         :param request: Request instance for ChannelCreateMultiFlowSignQRCode.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateMultiFlowSignQRCodeRequest`
